@@ -5,7 +5,7 @@
  * Copyright (C) 2015 Pavol Bauer
  * Copyright (C) 2017 -- 2019 Robin Eriksson
  * Copyright (C) 2015 -- 2019 Stefan Engblom
- * Copyright (C) 2015 -- 2020 Stefan Widgren
+ * Copyright (C) 2015 -- 2021 Stefan Widgren
  *
  * SimInf is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -84,6 +84,8 @@ SEXP attribute_hidden SimInf_ldata_sp(SEXP data, SEXP distance, SEXP metric)
     /* 1) Determine the maximum number of neighbors in the 'distance'
      * matrix and the number of neighbors (degree) for each node. */
     degree = malloc(Nn * sizeof(int));
+    if (!degree)
+        Rf_error("Unable to allocate memory buffer."); /* #nocov */
     Nld = 0;
     for (i = 0; i < Nn; i++) {
         const int k = jc[i + 1] - jc[i];
